==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/soda/classes/simple/STBoolean.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.query;
using com.db4o.test.soda;
namespace com.db4o.test.soda.classes.simple {

    public class STBoolean : STClass1 {
        [Transient] public static SodaTest st;
        public bool i_boolean;
      
        public STBoolean() : base() {
        }
      
        internal STBoolean(bool a_boolean) : base() {
            i_boolean = a_boolean;
        }
      
        public Object[] store() {
            return new Object[]{
                                   new STBoolean(false),
                                   new STBoolean(true),
                                   new STBoolean(false),
                                   new STBoolean(false)         };
        }
      
        public void testEqualsTrue() {
            Query q1 = st.query();
            q1.constrain(new STBoolean(true));
            Object[] r1 = store();
            st.expectOne(q1, new STBoolean(true));
        }
      
        public void testEqualsFalse() {
            Query q1 = st.query();
            q1.constrain(new STBoolean(false));
            q1.descend("i_boolean").constrain(System.Convert.ToBoolean(false));
            Object[] r1 = store();
            st.expect(q1, new Object[]{
                                          r1[0],
                                          r1[2],
                                          r1[3]         });
        }
    }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/soda/classes/simple/STBoolean.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.query;
using com.db4o.test.soda;
namespace com.db4o.test.soda.classes.simple {

    public class STBoolean : STClass1 {
        [Transient] public static SodaTest st;
        public bool i_boolean;
      
        public STBoolean() : base() {
        }
      
        internal STBoolean(bool a_boolean) : base() {
            i_boolean = a_boolean;
        }
      
        public Object[] Store() {
            return new Object[]{
                                   new STBoolean(false),
                                   new STBoolean(true),
                                   new STBoolean(false),
                                   new STBoolean(false)         };
        }
      
        public void TestEqualsTrue() {
            Query q1 = st.Query();
            q1.Constrain(new STBoolean(true));
            Object[] r1 = Store();
            st.ExpectOne(q1, new STBoolean(true));
        }
      
        public void TestEqualsFalse() {
            Query q1 = st.Query();
            q1.Constrain(new STBoolean(false));
            q1.Descend("i_boolean").Constrain(System.Convert.ToBoolean(false));
            Object[] r1 = Store();
            st.Expect(q1, new Object[]{
                                          r1[0],
                                          r1[2],
                                          r1[3]         });
        }
    }
}
